@@ -20,7 +20,8 @@ class CliConfig:
     server_port: int
     access_token_file: str
     refresh_token_file: str
-    oauth_token_file: str
+    oauth_access_token_file: str
+    remote_oauth_redirect_uri: str
 
 
 def load_config(
@@ -41,6 +42,9 @@ def load_config(
     if (teaspoons_api_url := config.get("TEASPOONS_API_URL")) is None:
         raise RuntimeError("Expected config value for API URL not found")
 
+    if (remote_oauth_redirect_uri := config.get("REMOTE_OAUTH_REDIRECT_URI")) is None:
+        raise RuntimeError("Expected config value for remote redirect_uri not found")
+
     return CliConfig(
         client_info=OAuth2ClientInfo.from_oidc_endpoint(
             config["OAUTH_OPENID_CONFIGURATION_URI"],
@@ -52,5 +56,6 @@ def load_config(
         server_port=int(server_port),
         access_token_file=f'{Path.home()}/{config["LOCAL_STORAGE_PATH"]}/access_token',
         refresh_token_file=f'{Path.home()}/{config["LOCAL_STORAGE_PATH"]}/refresh_token',
-        oauth_token_file=f'{Path.home()}/{config["LOCAL_STORAGE_PATH"]}/oauth_token',
+        oauth_access_token_file=f'{Path.home()}/{config["LOCAL_STORAGE_PATH"]}/oauth_access_token',
+        remote_oauth_redirect_uri=remote_oauth_redirect_uri,
     )
